<?php
/**
 * Registering meta boxes
 *
 * In this file, I'll show you how to extend the class to add more field type (in this case, the 'taxonomy' type)
 * All the definitions of meta boxes are listed below with comments, please read them carefully.
 * Note that each validation method of the Validation Class MUST return value instead of boolean as before
 *
 * You also should read the changelog to know what has been changed
 *
 * For more information, please visit: http://www.deluxeblogtips.com/2010/04/how-to-create-meta-box-wordpress-post.html
 *
 */

/********************* BEGIN EXTENDING CLASS ***********************/

/**
 * Extend RW_Meta_Box class
 * Add field type: 'taxonomy'
 */
class RW_Meta_Box_Taxonomy extends RW_Meta_Box {
	
	function add_missed_values() {
		parent::add_missed_values();
		
		// add 'multiple' option to taxonomy field with checkbox_list type
		foreach ($this->_meta_box['fields'] as $key => $field) {
			if ('taxonomy' == $field['type'] && 'checkbox_list' == $field['options']['type']) {
				$this->_meta_box['fields'][$key]['multiple'] = true;
			}
		}
	}
	
	// show taxonomy list
	function show_field_taxonomy($field, $meta) {
		global $post;
		
		if (!is_array($meta)) $meta = (array) $meta;
		
		$this->show_field_begin($field, $meta);
		
		$options = $field['options'];
		$terms = get_terms($options['taxonomy'], $options['args']);
		
		// checkbox_list
		if ('checkbox_list' == $options['type']) {
			foreach ($terms as $term) {
				echo "<input type='checkbox' name='{$field['id']}[]' value='$term->slug'" . checked(in_array($term->slug, $meta), true, false) . " /> $term->name<br/>";
			}
		}
		// select
		else {
			echo "<select name='{$field['id']}" . ($field['multiple'] ? "[]' multiple='multiple' style='height:auto'" : "'") . ">";
		
			foreach ($terms as $term) {
				echo "<option value='$term->slug'" . selected(in_array($term->slug, $meta), true, false) . ">$term->name</option>";
			}
			echo "</select>";
		}
		
		$this->show_field_end($field, $meta);
	}
}

/********************* END EXTENDING CLASS ***********************/

/********************* BEGIN DEFINITION OF META BOXES ***********************/

// prefix of meta keys, optional
// use underscore (_) at the beginning to make keys hidden, for example $prefix = '_rw_';
// you also can make prefix empty to disable it
$prefix = 'mom_';

$meta_boxes = array();


// residences meta box
$meta_boxes[] = array(
	'id' => 'article_setting',
	'title' => __('Article Setup', 'theme'),
	'pages' => array('post'),
	'priority' => 'high',


	'fields' => array(
		array(
			'name' => __('Article Type', 'theme'),
			'id' => $prefix . 'article_type',
			'type' => 'select',
			'std' => '',
			'options' => array (
				'article' => __('Article', 'theme'),
				'video' => __('Video', 'theme'),
				'slideshow' => __('Slideshow', 'theme')
			)

		),

		array(
			'name' => __('Full Width', 'theme'),
			'id' => $prefix . 'full_width',
			'type' => 'checkbox',
			'std' => false,
		),
		
		array(
			'name' => __('Show Feature Image', 'theme'),
			'id' => $prefix . 'show_feature',
			'type' => 'checkbox',
			'std' => false,
		),
		
	)
);

$meta_boxes[] = array(
	'id' => 'video_setting',
	'title' => __('Video Setting', 'theme'),
	'pages' => array('post'),
	'priority' => 'default',

	'fields' => array(

		array(
			'name' => __('Video Type', 'theme'),
			'id' => $prefix . 'video_type',
			'type' => 'select',
			'std' => '',
			'options' => array (
				'html5' => __('HTML5', 'theme'),
				'youtube' => __('Youtube', 'theme'),
				'vimeo' => __('Vimeo', 'theme'),
				'daily' => __('Dialymotion', 'theme')
			)

		),

		array(
			'name' => __('Show Video on post', 'theme'),
			'id' => $prefix . 'video_show',
			'type' => 'checkbox',
			'desc' => __('By default the video will be inserted on top of the post, if you want insert video manualy disable this.', 'theme'),
			'std' => true

		),
		
	)
);
// residences meta box
$meta_boxes[] = array(
	'id' => 'html_video_setting',
	'title' => __('HTML5 Video Setting', 'theme'),
	'pages' => array('post'),
	'priority' => 'default',

	'fields' => array(
		array(
			'name' => __('M4v url', 'theme'),
			'id' => $prefix . 'video_html_m4v',
			'type' => 'text',
			'std' => ''

		),
		array(
			'name' => __('Ogv url', 'theme'),
			'id' => $prefix . 'video_html_ogv',
			'type' => 'text',
			'std' => ''

		),

		array(
			'name' => __('Webmv url', 'theme'),
			'id' => $prefix . 'video_html_webm',
			'type' => 'text',
			'std' => ''

		),
		array(
			'name' => __('Poster Image', 'theme'),
			'id' => $prefix . 'video_html_poster',
			'type' => 'text',
			'std' => ''

		),

		), 
		
);

$meta_boxes[] = array(
	'id' => 'ex_video_setting',
	'title' => __('External Video Setting', 'theme'),
	'pages' => array('post'),
	'priority' => 'default',

	'fields' => array(

		array(
			'name' => __('Video ID', 'theme'),
			'id' => $prefix . 'video_id',
			'type' => 'text',
			'std' => ''

		),

	)
);

$meta_boxes[] = array(
	'id' => 'images_setting',
	'title' => __('The Slideshow', 'theme'),
	'pages' => array('post'),
	'priority' => 'default',
	'fields' => array(
		array(
			'name' => __('Hide SlideShow', 'theme'),
			'id' => $prefix . 'sh_slideshow',
			'type' => 'checkbox',
			'desc' => __('by default the slideshow is dispaly at the top of post if you want hide it set this ON', 'theme')
		),
		array(
			'name' => __('Slideshow Type', 'theme'),
			'id' => $prefix . 'slideshow_type',
			'type' => 'select',
			'std' => '',
			'options' => array (
				'slider' => __('slider ', 'theme'),
				'grid' => __('Grid ', 'theme')
			)

		),

		array(
			'name' => __('Upload The Images', 'theme'),
			'id' => $prefix . 'slideshow_imgs',
			'type' => 'plupload_image',
			'std' => ''

		),

	)
);
$rev_icon =  get_stylesheet_directory_uri() . '/framework/tinymce/images/rev_icon.png';
$rt_images =  get_stylesheet_directory_uri() . '/framework/metaboxes/img/momizat';

$meta_boxes[] = array(
	'id' => 'review',
	'title' => __('Review Settings', 'theme'),
	'pages' => array('post'),
	'priority' => 'default',
	'fields' => array(
		array(
			'name' => __('Enable Review', 'theme'),
			'id' => $prefix . 'enable_review',
			'type' => 'checkbox',
			'std' => false,
		),

		array(
			'name' => __('Review Position', 'theme'),
			'id' => $prefix . 'review_position',
			'type' => 'radio',
			'std' => 'bottom',
			'class' => 'review_position',
			'desc' => __('If you select <strong>Custom</strong> you can add the review manually by <img style="background:#fff; border:1px solid #e0e0e0; vertical-align:middle;" src="'. $rev_icon .'"> button in the editor', 'theme'),
			'options' => array (
				'top' => '<img class="radio_img" src="'. $rt_images . '/top.png">',
				'bottom' =>'<img class="radio_img" src="'. $rt_images . '/bottom.png">',
				'custom' => '<img class="radio_img" src="'. $rt_images . '/custom.png">'
			)
		),
		
		array(
			'name' => __('Review Style', 'theme'),
			'id' => $prefix . 'review_style',
			'type' => 'radio',
			'std' => 'stars',
			'options' => array (
				'stars' => '<img class="radio_img" src="'. $rt_images . '/stars.png">',
				'percent' =>'<img class="radio_img" src="'. $rt_images . '/percent.png">',
				'points' => '<img class="radio_img" src="'. $rt_images . '/point.png">'
			)
		),

		array(
			'name' => __('Review header', 'theme'),
			'id' => $prefix . 'review_head',
			'type' => 'text',
			'desc' => __('reviw box header leave blank to disable it', 'theme')
		),

		array(
			'name' => __('Review Footer', 'theme'),
			'id' => $prefix . 'review_foot',
			'type' => 'textarea',
			'class' => 'small_textearea',
			'desc' => __('reviw box footer leave blank to disable it', 'theme')
		),

		array(
			'name' => __('Review Summary', 'theme'),
			'id' => $prefix . 'review_summary',
			'type' => 'textarea',
			'class' => 'small_textearea',
			'std' => 'Summary: '
		),

		// score Title
		array(
			'name' => __('Score Title', 'theme'),
			'id' => $prefix . 'rt_score_title',
			'type' => 'text',
			'desc' => __('the text under the score eg: Awesome, Great, Must Buy', 'theme'),
			'std' => 0,
		),

	)
);

$meta_boxes[] = array(
	'id' => 'review_cr',
	'title' => __('Review Criterias', 'theme'),
	'pages' => array('post'),
	'priority' => 'default',
	'fields' => array(

		//CR 1
		array(
			'name' => '<span class="rt_desc">Criteria 1:</span> Name',
			'id' => $prefix . 'rt_cr1_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 1:</span> Rate',
			'id' => $prefix . 'rt_cr1_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr1_stars_rt_prev">--</em> - points = <em class="cr1_points_rt_prev">--</em>', 'theme')
		),

		//CR 2
		array(
			'name' => '<span class="rt_desc">Criteria 2:</span> Name',
			'id' => $prefix . 'rt_cr2_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 2:</span> Rate',
			'id' => $prefix . 'rt_cr2_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr2_stars_rt_prev">--</em> - points = <em class="cr2_points_rt_prev">--</em>', 'theme')
		),

		//CR 3
		array(
			'name' => '<span class="rt_desc">Criteria 3:</span> Name',
			'id' => $prefix . 'rt_cr3_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 3:</span> Rate',
			'id' => $prefix . 'rt_cr3_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr3_stars_rt_prev">--</em> - points = <em class="cr3_points_rt_prev">--</em>', 'theme')
		),

		//CR 4
		array(
			'name' => '<span class="rt_desc">Criteria 4:</span> Name',
			'id' => $prefix . 'rt_cr4_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 4:</span> Rate',
			'id' => $prefix . 'rt_cr4_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr4_stars_rt_prev">--</em> - points = <em class="cr4_points_rt_prev">--</em>', 'theme')
		),

		//CR 5
		array(
			'name' => '<span class="rt_desc">Criteria 5:</span> Name',
			'id' => $prefix . 'rt_cr5_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 5:</span> Rate',
			'id' => $prefix . 'rt_cr5_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr5_stars_rt_prev">--</em> - points = <em class="cr5_points_rt_prev">--</em>', 'theme')
		),

		//CR 6
		array(
			'name' => '<span class="rt_desc">Criteria 6:</span> Name',
			'id' => $prefix . 'rt_cr6_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 6:</span> Rate',
			'id' => $prefix . 'rt_cr6_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr6_stars_rt_prev">--</em> - points = <em class="cr6_points_rt_prev">--</em>', 'theme')
		),

		//CR 7
		array(
			'name' => '<span class="rt_desc">Criteria 7:</span> Name',
			'id' => $prefix . 'rt_cr7_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 7:</span> Rate',
			'id' => $prefix . 'rt_cr7_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr7_stars_rt_prev">--</em> - points = <em class="cr7_points_rt_prev">--</em>', 'theme')
		),

		//CR 8
		array(
			'name' => '<span class="rt_desc">Criteria 8:</span> Name',
			'id' => $prefix . 'rt_cr8_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 8:</span> Rate',
			'id' => $prefix . 'rt_cr8_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr8_stars_rt_prev">--</em> - points = <em class="cr8_points_rt_prev">--</em>', 'theme')
		),

		//CR 9
		array(
			'name' => '<span class="rt_desc">Criteria 9:</span> Name',
			'id' => $prefix . 'rt_cr9_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 9:</span> Rate',
			'id' => $prefix . 'rt_cr9_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr9_stars_rt_prev">--</em> - points = <em class="cr9_points_rt_prev">--</em>', 'theme')
		),

		//CR 10
		array(
			'name' => '<span class="rt_desc">Criteria 10:</span> Name',
			'id' => $prefix . 'rt_cr10_desc',
			'type' => 'text',
		),

		array(
			'name' => '<span class="rt_desc">Criteria 10:</span> Rate',
			'id' => $prefix . 'rt_cr10_rate',
			'type' => 'range',
			'min' => 0,
			'max' => 100,
			'step' => 1,
			'std' => '',
			'suffix' => '%',
			'class' => 'divider',
			'desc' => __('stars = <em class="cr10_stars_rt_prev">--</em> - points = <em class="cr10_points_rt_prev">--</em>', 'theme')
		),


		//final score
		array(
			'name' => '<span class="rt_fs_desc">Score %</span>',
			'id' => $prefix . 'rt_final_score',
			'type' => 'text',
			'std' => 0,
			'class' => 'rt_final_score'
		),

		//final score
		array(
			'name' => '<span class="rt_fs_desc">Score *</span>',
			'id' => $prefix . 'rt_final_score_stars',
			'type' => 'text',
			'std' => 0,
			'class' => 'rt_final_score_stars'
		),

		array(
			'name' => '<span class="rt_fs_desc">Score 8/10</span>',
			'id' => $prefix . 'rt_final_score_po',
			'type' => 'text',
			'std' => 0,
			'class' => 'rt_final_score_po'
		),
		
	)
);
// pages 
$imagepath =  get_stylesheet_directory_uri() . '/builder/js_composer/assets/images/momizat';

$meta_boxes[] = array(
	'id' => 'Page_builder',
	'title' => __('Page Builder Sittengs', 'theme'),
	'pages' => array('page'),
	'priority' => 'default',
	'fields' => array(
		array(
			'name' => __('Enable builder', 'theme'),
			'id' => $prefix . 'enable_builder',
			"desc" => "this option must be on if you want make this page as a home page or build it as fully custom page",
			'type' => 'checkbox',
			'std' => false,
		),

		array(
			'id' => $prefix . 'page_layout',
			'type' => 'radio',
			'std' =>'rightside',
			'class' => 'hide bulider_layout',
			'options' => array (
				'leftside' => '<img class="radio_img" src="'. $imagepath . '/lside.png">',
				'fullwidth' =>'<img class="radio_img" src="'. $imagepath . '/fullw.png">',
				'rightside' => '<img class="radio_img" src="'. $imagepath . '/rside.png">'
			)
		),


	)
);

$meta_boxes[] = array(
	'id' => 'page_comments',
	'title' => __('Page Comments', 'theme'),
	'pages' => array('page'),
	'priority' => 'default',
	'fields' => array(
		array(
			'name' => __('Enable Comments', 'theme'),
			'id' => $prefix . 'page_comments',
			'type' => 'checkbox',
			'std' => false,
		),


	)
);


foreach ($meta_boxes as $meta_box) {
	new RW_Meta_Box_Taxonomy($meta_box);
}

/********************* END DEFINITION OF META BOXES ***********************/

/********************* BEGIN VALIDATION ***********************/

/**
 * Validation class
 * Define ALL validation methods inside this class
 * Use the names of these methods in the definition of meta boxes (key 'validate_func' of each field)
 */
class RW_Meta_Box_Validate {
	function check_name($text) {
		if ($text == 'Anh Tran') {
			return 'He is Rilwis';
		}
		return $text;
	}
}

/********************* END VALIDATION ***********************/
?>
